#
# spec file for package python-WebOb
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-WebOb
Version:        1.6.2
Release:        7.1
Summary:        WSGI request and response object
License:        MIT
Group:          Development/Languages/Python
Url:            http://webob.org/
Source:         https://pypi.io/packages/source/W/WebOb/WebOb-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Test requirements:
# for ssl module:
BuildRequires:  python
BuildRequires:  python-nose
# Documentation requirements:
BuildRequires:  python-Sphinx
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       python-webob = %{version}
Obsoletes:      python-webob < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
WebOb provides wrappers around the WSGI request environment, and an
object to help create WSGI responses.

The objects map much of the specified behavior of HTTP, including
header parsing and accessors for other standard parts of the
environment.

%package doc
Summary:        WSGI request and response object - Documentation
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n WebOb-%{version}

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python setup.py test

%files
%defattr(-,root,root,-)
%doc docs/license.txt
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc build/sphinx/html

%changelog
* Sat Oct 15 2016 dmueller@suse.com
- update to 1.6.2:
  * WebOb's exceptions will lazily read underlying variables when inserted into
  templates to avoid expensive computations/crashes when inserting into the
  template. This had a bad performance regression on Py27 because of the way
  the lazified class was created and returned. See
  https://github.com/Pylons/webob/pull/284
* Mon Jun  6 2016 dmueller@suse.com
- fix download url
* Fri Jun  3 2016 tbechtold@suse.com
- update to 1.6.1:
  - Response.from_file now parses the status line correctly when the status line
    contains an HTTP with version, as well as a status text that contains
    multiple white spaces (e.g 404 Not Found). See
    https://github.com/Pylons/webob/issues/250
  - Python 3.2 is no longer supported by WebOb
  - Request.decode attempted to read from the an already consumed stream, it has
    now been redirected to another stream to read from. See
    https://github.com/Pylons/webob/pull/183
  - The application/json media type does not allow for a charset as discovery of
    the encoding is done at the JSON layer. Upon initialization of a Response
    WebOb will no longer add a charset if the content-type is set to JSON. See
    https://github.com/Pylons/webob/pull/197 and
    https://github.com/Pylons/pyramid/issues/1611
  - Lazily HTML escapes environment keys in HTTP Exceptions so that those keys in
    the environ that are not used in the output of the page don't raise an
    exception due to inability to be properly escaped. See
    https://github.com/Pylons/webob/pull/139
  - MIMEAccept now accepts comparisons against wildcards, this allows one to
    match on just the media type or sub-type, without having to explicitly match
    on both the media type and sub-type at the same time. See
    https://github.com/Pylons/webob/pull/185
  - Add the ability to return a JSON body from an exception. Using the Accept
    information in the request, the exceptions will now automatically return a
    JSON version of the exception instead of just HTML or text. See
    https://github.com/Pylons/webob/pull/230 and
    https://github.com/Pylons/webob/issues/209
  - exc._HTTPMove and any subclasses will now raise a ValueError if the location
    field contains a line feed or carriage return. These values may lead to
    possible HTTP Response Splitting. The header_getter descriptor has also been
    modified to no longer accept headers with a line feed or carriage return.
    See: https://github.com/Pylons/webob/pull/229 and
    https://github.com/Pylons/webob/issues/217
* Mon Dec 14 2015 aplanas@suse.com
- updateto version 1.5.1:
  * (Bug Fixes) The exceptions HTTPNotAcceptable,
    HTTPUnsupportedMediaType and HTTPNotImplemented will now correctly
    use the sub-classed template rather than the default error
    template. See https://github.com/Pylons/webob/issues/221
  * (Bug Fixes) Response’s from_file now correctly deals with a status
    line that contains an HTTP version identifier. HTTP/1.1 200 OK is
    now correctly parsed, whereas before this would raise an error
    upon setting the Response.status in from_file. See
    https://github.com/Pylons/webob/issues/121
- 1.5.0
  * (Bug Fixes) The cookie API functions will now make sure that
    max_age is an integer or an string that can convert to an
    integer. Previously passing in max_age=’test’ would have silently
    done the wrong thing.
- 1.5.0b0
  * (Bug Fixes) Unbreak req.POST when the request method is
    PATCH. Instead of returning something cmpletely unrelated we
    return NoVar. See: https://github.com/Pylons/webob/pull/215
  * (Features) HTTP Status Code 308 is now supported as a Permanent
    Redirect. See https://github.com/Pylons/webob/pull/207
- 1.5.0a1
  * (Backwards Incompatibilities) Response.set_cookie renamed the only
    required parameter from “key” to “name”. The code will now still
    accept “key” as a keyword argument, and will issue a
    DeprecationWarning until WebOb 1.7.
  * (Backwards Incompatibilities) The status attribute of a Response
    object no longer takes a string like None None and allows that to
    be set as the status. It now has to at least match the pattern of
    <integer status code> <explenation of status code>. Invalid status
    strings will now raise a ValueError.
- 1.5.0a0
  * (Backwards Incompatibilities) Morsel will no longer accept a
    cookie value that does not meet RFC6265’s cookie-octet
    specification. Upon calling Morsel.serialize a warning will be
    issued, in the future this will raise a ValueError, please update
    your cookie handling code. See
    https://github.com/Pylons/webob/pull/172
  * (Backwards Incompatibilities) Response.set_cookie now uses the
    internal make_cookie API, which will issue warnings if cookies are
    set with invalid bytes. See
    https://github.com/Pylons/webob/pull/172
  * (Features) Add support for some new caching headers,
    stale-while-revalidate and stale-if-error that can be used by
    reverse proxies to cache stale responses temporarily if the
    backend disappears. From RFC5861. See
    https://github.com/Pylons/webob/pull/189
  * (Bug Fixes) Response.status now uses duck-typing for integers, and
    has also learned to raise a ValueError if the status isn’t an
    integer followed by a space, and then the reason. See
    https://github.com/Pylons/webob/pull/191
  * (Bug Fixes) Fixed a bug in webob.multidict.GetDict which resulted
    in the QUERY_STRING not being updated when changes were made to
    query params using Request.GET.extend().
  * (Bug Fixes) Read the body of a request if we think it might have a
    body. This fixes PATCH to support bodies. See
    https://github.com/Pylons/webob/pull/184
  * (Bug Fixes) Response.from_file returns HTTP headers as latin1
    rather than UTF-8, this fixes the usage on Google AppEngine. See
    https://github.com/Pylons/webob/issues/99 and
    https://github.com/Pylons/webob/pull/150
  * (Bug Fixes) Fix a bug in parsing the auth parameters that
    contained bad white space. This makes the parsing fall in line
    with what’s required in RFC7235. See
    https://github.com/Pylons/webob/issues/158
  * (Bug Fixes) Use ‘rn’ line endings in Response.__str__. See:
    https://github.com/Pylons/webob/pull/146
  * (Documentation Changes) response.set_cookie now has proper
    documentation for max_age and expires. The code has also been
    refactored to use cookies.make_cookie instead of duplicating the
    code. This fixes https://github.com/Pylons/webob/issues/166 and
    https://github.com/Pylons/webob/issues/171
  * (Documentation Changes) Documentation didn’t match the actual code
    for the wsgify function signature. See
    https://github.com/Pylons/webob/pull/167
  * (Documentation Changes) Remove the WebDAV only from certain HTTP
    Exceptions, these exceptions may also be used by REST services for
    example.
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 1.4:
  * Remove ``webob.__version__``, the version number had not been kept in sync
    with the official pkg version.  To obtain the WebOb version number, use
    ``pkg_resources.get_distribution('webob').version`` instead.
  * Fix a bug in ``EmptyResponse`` that prevents it from setting self.close as
    appropriate due to testing truthiness of object rather than if it is
    something other than ``None``.
  * Fix a bug in ``SignedSerializer`` preventing secrets from containing
    higher-order characters. See https://github.com/Pylons/webob/issues/136
  * Use the ``hmac.compare_digest`` method when available for constant-time
    comparisons.
  * Fix a bug in ``SignedCookieProfile`` whereby we didn't keep the original
    serializer around, this would cause us to have ``SignedSerializer`` be added
    on top of a ``SignedSerializer`` which would cause it to be run twice when
    attempting to verify a cookie.  See https://github.com/Pylons/webob/pull/127
  * Backwards Incompatible change: When ``CookieProfile.get_value`` and
    ``SignedCookieProfile.get_value`` fails to deserialize a badly encoded
    value, we now return ``None`` as if the cookie was never set in the first
    place instead of allowing a ``ValueError`` to be raised to the calling code.
    See https://github.com/Pylons/webob/pull/126
  * Added a read-only ``domain`` property to ``BaseRequest``.  This property
    returns the domain portion of the host value.  For example, if the
    environment contains an ``HTTP_HOST`` value of ``foo.example.com:8000``,
    ``request.domain`` will return ``foo.example.com``.
  * Added five new APIs: ``webob.cookies.CookieProfile``,
    ``webob.cookies.SignedCookieProfile``, ``webob.cookies.JSONSerializer`` and
    ``webob.cookies.SignedSerializer``, and ``webob.cookies.make_cookie``. These
    APIs are convenience APIs for generating and parsing cookie headers as well
    as dealing with signing cookies.
  * Cookies generated via webob.cookies quoted characters in cookie values that
    did not need to be quoted per RFC 6265.  The following characters are no
    longer quoted in cookie values: ``~/=<>()[]{}?@`` .  The full set of
    non-letter-or-digit unquoted cookie value characters is now
    ``!#$%%&'*+-.^_`|~/: =<>()[]{}?@``.  See
    http://tools.ietf.org/html/rfc6265#section-4.1.1 for more information.
  * Cookie names are now restricted to the set of characters expected by RFC
    6265.  Previously they could contain unsupported characters such as ``/``.
  * Older versions of Webob escaped the doublequote to ``\"`` and the backslash
    to ``\\`` when quoting cookie values.  Now, instead, cookie serialization
    generates ``\042`` for the doublequote and ``\134`` for the backslash. This
    is what is expected as per RFC 6265.  Note that old cookie values that do
    have the older style quoting in them will still be unquoted correctly,
    however.
  * Added support for draft status code 451 ("Unavailable for Legal Reasons").
    See http://tools.ietf.org/html/draft-tbray-http-legally-restricted-status-00
  * Added status codes 428, 429, 431 and 511 to ``util.status_reasons`` (they
    were already present in a previous release as ``webob.exc`` exceptions).
  * MIMEAccept happily parsed malformed wildcard strings like "image/pn*" at
    parse time, but then threw an AssertionError during matching.  See
    https://github.com/Pylons/webob/pull/83 .
  * Preserve document ordering of GET and POST request data when POST data
    passed to Request.blank is a MultiDict.
    See https://github.com/Pylons/webob/pull/96
  * Allow query strings attached to PATCH requests to populate request.params.
    See https://github.com/Pylons/webob/pull/106
  * Added Python 3.3 trove classifier.
* Tue Feb 18 2014 ro@suse.de
- added license.txt as doc file
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Mar 27 2013 speilicke@suse.com
- BuildRequire python (for ssl module) and drop pyOpenSSL
* Mon Jan 14 2013 saschpe@suse.de
- (Build)Require python-pyOpenSSL instead of M2Crypto (to get the
  ssl Python base module)
* Fri Nov 23 2012 saschpe@suse.de
- Add dependency on python-M2Crypto, otherwise you won't get HTTPS
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 1.2.3:
  + Fix parsing of form submissions where fields have transfer-content-encoding headers.
- Build HTML documentation
- Run testsuite
- Split of doc package
* Sat Sep 22 2012 os-dev@jacraig.com
- Update to 1.2.2:
  * Fix multiple calls to ``cache_expires()`` not fully overriding the
    previously set headers.
  * Fix parsing of form submissions where fields have different encodings.
- Many changes between versions 1.1.1 and 1.2.1.  Please see docs/news.txt
  for full details.  Major changes include support for only Python 3.2, 2.7,
  2.6.
- Removed dependency on python-Tempita and python-wsgiproxy: these are only
  used in example code in the documentation and not actual runtime reqs.
- Removed dependency on python-nose: it is only needed to run tests.
- Removed dependency on python-WebTest: it was removed as a testing
  requirement in 1.2a1.
* Mon Nov 28 2011 prusnak@opensuse.org
- spec cleanup
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 1.1.1:
  * Fix disconnect detection being incorrect in some cases
  * Fix exception when calling .accept.best_match(..) on a header containing
    '*' (instead of '*/*')
  * Split Accept class into appropriate subclasses (AcceptCharset,
    AcceptLanguage)
  * Improve language matching code so that 'en' in AcceptLanguage('en-gb')
    (the app can now offer a generic 'en' and it will match any of the
    accepted dialects) and 'en_GB' in AcceptLanguage('en-gb') (normalization
    of the dash/underscode in language names).
  * Deprecate req.etag.weak_match(..)
  * Deprecate Response.request and Response.environ attrs.
* Thu Sep  1 2011 saschpe@suse.de
- Initial version
